@@ -142,8 +142,6 @@ protected:
 SYNCEVOLUTION_TEST_SUITE_REGISTRATION(EvolutionContactTest);
 #endif // ENABLE_UNIT_TESTS
 
-#ifdef ENABLE_INTEGRATION_TESTS
-
 namespace {
 #if 0
 }
@@ -182,7 +180,6 @@ public:
 } vCard30Test;
 
 }
-#endif // ENABLE_INTEGRATION_TESTS
 
 #endif // ENABLE_EBOOK
 
