@@ -98,6 +98,27 @@ const char *SyncEvolutionXML =
 "      $VCALENDAR_10TO20_PRIORITY_CONVERSION;\n"
 "    ]]></macro>\n"
 "\n"
+"    <macro name=\"VCARD_INCOMING_NAMECHANGE_SCRIPT\"><![CDATA[\n"
+"      STRING tmp;\n"
+"      tmp=NORMALIZED(FN);\n"
+"      if (tmp==EMPTY){\n"
+"        tmp=N_FIRST;\n"
+"        if (N_MIDDLE != EMPTY) {\n"
+"          if (tmp != EMPTY) {\n"
+"            tmp = tmp + \" \";\n"
+"          }\n"
+"          tmp = tmp + N_MIDDLE;\n"
+"        }\n"
+"        if (N_LAST != EMPTY) {\n"
+"          if (tmp != EMPTY) {\n"
+"            tmp = tmp + \" \";\n"
+"          }\n"
+"          tmp = tmp + N_LAST;\n"
+"        }\n"
+"        FN = tmp;\n"
+"      }\n"
+"    ]]></macro>\n"
+"\n"
 "		<!-- define script macros for scripts that are used by both vCalendar 1.0 and iCalendar 2.0 -->\n"
 "\n"
 "    <macro name=\"VCALENDAR_INCOMING_SCRIPT\"><![CDATA[\n"
@@ -200,7 +221,6 @@ const char *SyncEvolutionXML =
 "      }\n"
 "    ]]></macro>\n"
 "\n"
-"\n"
 "    <macro name=\"VCALENDAR_OUTGOING_SCRIPT\"><![CDATA[\n"
 "      // set UTC time of generation for iCalendar 2.0 DTSTAMP\n"
 "      DGENERATED = NOW();\n"
@@ -265,6 +285,8 @@ const char *SyncEvolutionXML =
 "      <field name=\"FN\" type=\"string\" compare=\"conflict\" merge=\"fillempty\"/>\n"
 "      <field name=\"FILE-AS\" type=\"string\" compare=\"conflict\" merge=\"fillempty\"/>\n"
 "\n"
+"      <field name=\"GENDER\" type=\"string\" compare=\"conflict\" merge=\"fillempty\"/>\n"
+"\n"
 "      <!-- categories and classification -->\n"
 "      <field name=\"CATEGORIES\" array=\"yes\" type=\"string\" compare=\"conflict\"/>\n"
 "\n"
@@ -330,6 +352,10 @@ const char *SyncEvolutionXML =
 "      <field name=\"MSN_SLOT\"          array=\"yes\" type=\"string\" compare=\"conflict\"/>\n"
 "      <field name=\"YAHOO_HANDLE\"        array=\"yes\" type=\"string\" compare=\"conflict\"/>\n"
 "      <field name=\"YAHOO_SLOT\"          array=\"yes\" type=\"string\" compare=\"conflict\"/>\n"
+"      <field name=\"SKYPE_HANDLE\"      array=\"yes\" type=\"string\" compare=\"conflict\"/>\n"
+"      <field name=\"SKYPE_SLOT\"        array=\"yes\" type=\"string\" compare=\"conflict\"/>\n"
+"      <field name=\"SIP_HANDLE\"        array=\"yes\" type=\"string\" compare=\"conflict\"/>\n"
+"      <field name=\"SIP_SLOT\"          array=\"yes\" type=\"string\" compare=\"conflict\"/>\n"
 "\n"
 "      <!-- home address -->\n"
 "      <field name=\"ADR_STREET\"        array=\"yes\" type=\"multiline\" compare=\"conflict\"/>\n"
@@ -384,6 +410,10 @@ const char *SyncEvolutionXML =
 "          <value field=\"FILE-AS\"/>\n"
 "        </property>\n"
 "\n"
+"        <property name=\"X-GENDER\">\n"
+"          <value field=\"GENDER\"/>\n"
+"        </property>\n"
+"\n"
 "        <!-- onlyformode=\"standard\": not part of vCard 2.1, but some\n"
 "             peers (like the Funambol server) accept it anyway in\n"
 "             vCard 2.1 -->\n"
@@ -579,6 +609,20 @@ const char *SyncEvolutionXML =
 "          </parameter>\n"
 "        </property>\n"
 "\n"
+"        <property name=\"X-SKYPE\" suppressempty=\"yes\"> \n"
+"          <value field=\"SKYPE_HANDLE\"/>\n"
+"          <parameter name=\"X-EVOLUTION-UI-SLOT\" positional=\"no\" show=\"yes\">\n"
+"            <value field=\"SKYPE_SLOT\"/>\n"
+"          </parameter>\n"
+"        </property>\n"
+"\n"
+"        <property name=\"X-SIP\" suppressempty=\"yes\">\n"
+"          <value field=\"SIP_HANDLE\"/>\n"
+"          <parameter name=\"X-EVOLUTION-UI-SLOT\" positional=\"no\" show=\"yes\">\n"
+"            <value field=\"SIP_SLOT\"/>\n"
+"          </parameter>\n"
+"        </property>\n"
+"\n"
 "        <property name=\"ADR\" values=\"7\">\n"
 "          <value index=\"0\" field=\"ADR_POBOX\"/>\n"
 "          <value index=\"1\" field=\"ADR_ADDTL\"/>\n"
@@ -624,12 +668,18 @@ const char *SyncEvolutionXML =
 "    <datatype name=\"vCard21\" basetype=\"vcard\">\n"
 "      <version>2.1</version>\n"
 "      <use mimeprofile=\"vCard\"/>\n"
+"     <incomingscript><![CDATA[\n"
+"        $VCARD_INCOMING_NAMECHANGE_SCRIPT\n"
+"      ]]></incomingscript>\n"
 "    </datatype>\n"
 "\n"
 "    <!-- vCard 3.0 datatype, using vCard profile defined above -->\n"
 "    <datatype name=\"vCard30\" basetype=\"vcard\">\n"
 "      <version>3.0</version>\n"
 "      <use mimeprofile=\"vCard\"/>\n"
+"      <incomingscript><![CDATA[\n"
+"        $VCARD_INCOMING_NAMECHANGE_SCRIPT\n"
+"      ]]></incomingscript>\n"
 "    </datatype>\n"
 "\n"
 "\n"
@@ -1220,7 +1270,7 @@ const char *SyncEvolutionXML =
 "      <incomingscript><![CDATA[\n"
 "        $VCALENDAR_INCOMING_SCRIPT\n"
 "      ]]></incomingscript>\n"
-"\n"
+"      \n"
 "      <outgoingscript><![CDATA[\n"
 "        $VCALENDAR_OUTGOING_SCRIPT\n"
 "      ]]></outgoingscript>\n"
@@ -1237,6 +1287,7 @@ const char *SyncEvolutionXML =
 "        $VCALENDAR_INCOMING_SCRIPT\n"
 "      ]]></incomingscript>\n"
 "\n"
+"\n"
 "      <outgoingscript><![CDATA[\n"
 "        $VCALENDAR_OUTGOING_SCRIPT\n"
 "      ]]></outgoingscript>\n"
